# Kapitel 20 - geplante Kontraste auf 3 Wegen berechnet

# Alternative 1: Pakete nlme und multicomp

# Weiten Datensatz erzeugen
dfweit <- data.frame(ID=c(1,2,3,4,5,6,7,8,9,10), 
                     Ibuprofen=c(4,5,7,5,4,5,6,6,4,4), 
                     Aspirin=c(5,5,6,7,3,6,5,7,5,4), 
                     Placebo=c(8,9,7,8,7,7,7,6,7,5))

# Installieren und Aktivieren des Pakets reshape2
install.packages("reshape2")
library(reshape2)

# Erzeugen des langen Datensatzes
dflang <- reshape2::melt(dfweit, id="ID")

# Festlegen der Spaltenköpfe
colnames(dflang) <- c("ID", "Medikament", "Schmerzlinderung")

# Installieren und Aktivieren des Pakets psych
install.packages("psych")
library(psych)

# Medikamentenbezogene deskriptive Statistik
describeBy(datensatzlang$Schmerzlinderung, datensatzlang$Medikament)

# Reihenfolge der Medikamente in den levels
levels(datensatzlang$Medikament)

# Festlegung der Kontraste
contrasts(dflang$Medikament) <- cbind("Ibuprofen vs. Placebo"=c(1,0,-1), "Aspirin vs. Placebo"=c(0,1,-1))

# Installieren und Aktivieren des Pakets nlme
install.packages("nlme")
library(nlme)

# Berechnung des linearen Modells und Ergebnisspeicherung in Resultatlme
Resultatlme <- nlme::lme(Schmerzlinderung ~ Medikament, random = ~1|ID/Medikament, data=dflang, method="ML")

# Ergebnisdarstellung
summary(Resultatlme)

# Installieren und Aktivieren des Pakets multcomp
install.packages("multcomp")
library(multcomp)

# Berechnen des Kontrastmodells 1
Kontrastmodell1 <- multcomp::glht(Resultatlme, linfct=multcomp::mcp(Medikament=rbind("Ibuprofen vs. Placebo"=c(1,0,-1), "Aspirin vs. Placebo"=c(0,1,-1))))

# Ergebnisse des Kontrastmodells mit Bonferroni-Adjustierung
summary(Kontrastmodell1, test = multcomp::adjusted("bonf"))

# nicht-adjustiertes Konfidenzintervall des Kontrastmodells1 
confint(Kontrastmodell1)

# Festlegen der Kontraste für das Kontrastmodell2
contrasts(dflang$Medikament) <- cbind("Ibuprofen vs. Placebo"=c(1,0,-1), "Aspirin vs. Placebo"=c(0,1,-1), "Ibuprofen vs. Aspirin"=c(1,-1,0))

# Speicherung des linearen Modells in Resultatlme
Resultatlme <- nlme::lme(Schmerzlinderung ~ Medikament, random = ~1|ID/Medikament, data=dflang, method="ML")

# Berechnung des Kontrastmodells2
Kontrastmodell2 <- multcomp::glht(Resultatlme, linfct=multcomp::mcp(Medikament= rbind("Ibuprofen vs. Placebo"=c(1,0,-1), "Aspirin vs. Placebo"=c(0,1,-1), "Ibuprofen vs. Aspirin"=c(1,-1,0))))

# Ergebnisse des Kontrastmodells2 
summary(Kontrastmodell2, test = multcomp::adjusted("bonf"))

# Berechnung der Effektgröße r für das Kontrastmodell
r_contrast <- function(t, df){return(sqrt((t^2)/(t^2 + df)))} 


# Alternative 2: Paket lmerTest

# Installieren und Aktivieren des Pakets lmerTest
install.packages("lmerTest")
library(lmerTest)

# Speicherung der lmer als Objekt Anovamodell
Anovamodell <- lmer(Schmerzlinderung ~ Medikament + (1|Teilnehmende), data=datensatzlang)

# ANOVA zum Anovamodell
anova(Anovamodell)


# Alternative 3: Paket emmeans

# Installieren und Aktivieren des Pakets emmeans
install.packages("emmeans")
library(emmeans)

# Speicherung der Anova im Objekt modell
modell <- aov(Schmerzlinderung~Medikament, data=datensatzlang)

# Berechnung der Kontraste 
contrast(emmeans(modell, "Medikament"), list("A - C" = c(1,0, -1), "B - C" = c(0, 1,-1)))
